Index: src/compiler/ast-graph-builder.h |
diff --git a/src/compiler/ast-graph-builder.h b/src/compiler/ast-graph-builder.h |
index f5b662224a0a95e8629a2fa4b54848c5c95ee51e..87bfde50f8623ec6dcaf211d220e5639c914deb2 100644 |
--- a/src/compiler/ast-graph-builder.h |
+++ b/src/compiler/ast-graph-builder.h |
@@ -87,6 +87,7 @@ class AstGraphBuilder : public AstVisitor { |
// Nodes representing values in the activation record. |
SetOncePointer<Node> function_closure_; |
SetOncePointer<Node> function_context_; |
+ SetOncePointer<Node> incoming_new_target_; |
// Tracks how many try-blocks are currently entered. |
int try_catch_nesting_level_; |
@@ -147,13 +148,16 @@ class AstGraphBuilder : public AstVisitor { |
// Create the main graph body by visiting the AST. |
void CreateGraphBody(bool stack_check); |
// Get or create the node that represents the outer function closure. |
Node* GetFunctionClosureForContext(); |
Node* GetFunctionClosure(); |
// Get or create the node that represents the outer function context. |
Node* GetFunctionContext(); |
+ // Get or create the node that represents the incoming new target value. |
+ Node* GetIncomingNewTarget(); |
Benedikt Meurer
2015/11/23 05:24:21
I don't have a strong opinion on this, but why did
Michael Starzinger
2015/11/23 11:40:26
Done. You are right. Dropped the "Incoming", just
|
+ |
// Node creation helpers. |
Node* NewNode(const Operator* op, bool incomplete = false) { |
return MakeNode(op, 0, static_cast<Node**>(NULL), incomplete); |
@@ -147,13 +148,16 @@ class AstGraphBuilder : public AstVisitor { |
// Create the main graph body by visiting the AST. |
void CreateGraphBody(bool stack_check); |
- // Get or create the node that represents the outer function closure. |
+ // Get or create the node that represents the incoming function closure. |
Node* GetFunctionClosureForContext(); |
Node* GetFunctionClosure(); |
@@ -147,13 +148,16 @@ class AstGraphBuilder : public AstVisitor { |
Node* GetFunctionClosureForContext(); |
Node* GetFunctionClosure(); |
- // Get or create the node that represents the outer function context. |
+ // Get or create the node that represents the incoming function context. |
Node* GetFunctionContext(); |